# artisinal_integers
get a unqiue artisinal integer from one of many providers

## Installation

    $ pip install artisinal_integers

## Use

Currently you can create integers from Brooklyn Integers. By default you can fetch a single integer, or set the "num" parameter to the number of integers you want, limit 10!

    import artisinal_integers

    artisinal_integers.create_brooklyn_integer(4)


    